@@ -1,4 +1,4 @@
-# Copyright (C) 2017-2020  The Software Heritage developers
+# Copyright (C) 2017-2021  The Software Heritage developers
 # See the AUTHORS file at the top-level directory of this distribution
 # License: GNU General Public License version 3, or any later version
 # See top-level LICENSE file for more information
@@ -6,20 +6,26 @@
 from django.shortcuts import render
 from django.urls import reverse
 
-from ..config import COL_IRI
-from ..models import DepositClient, DepositCollection
-from .common import ACCEPT_ARCHIVE_CONTENT_TYPES, ACCEPT_PACKAGINGS, APIBase
+from swh.deposit.api.common import (
+    ACCEPT_ARCHIVE_CONTENT_TYPES,
+    ACCEPT_PACKAGINGS,
+    APIBase,
+)
+from swh.deposit.config import COL_IRI
+from swh.deposit.models import DepositClient, DepositCollection
 
 
 class ServiceDocumentAPI(APIBase):
-    def get(self, req, *args, **kwargs):
-        client = DepositClient.objects.get(username=req.user)
+    def get(self, request, *args, **kwargs):
+        if isinstance(request.user, DepositClient):
+            client = request.user
+        else:
+            client = DepositClient.objects.get(username=request.user)
 
         collections = {}
-
         for col_id in client.collections:
             col = DepositCollection.objects.get(pk=col_id)
-            col_uri = req.build_absolute_uri(reverse(COL_IRI, args=[col.name]))
+            col_uri = request.build_absolute_uri(reverse(COL_IRI, args=[col.name]))
             collections[col.name] = col_uri
 
         context = {
@@ -29,5 +35,8 @@ class ServiceDocumentAPI(APIBase):
             "collections": collections,
         }
         return render(
-            req, "deposit/service_document.xml", context, content_type="application/xml"
+            request,
+            "deposit/service_document.xml",
+            context,
+            content_type="application/xml",
         )
