@@ -29,7 +29,6 @@ PRIVATE_GET_DEPOSIT_METADATA = "private-read"
 PRIVATE_LIST_DEPOSITS = "private-deposit-list"
 
 ARCHIVE_KEY = "archive"
-METADATA_KEY = "metadata"
 RAW_METADATA_KEY = "raw-metadata"
 
 ARCHIVE_TYPE = "archive"
@@ -44,7 +43,7 @@ DEPOSIT_STATUS_VERIFIED = "verified"
 DEPOSIT_STATUS_LOAD_SUCCESS = "done"
 DEPOSIT_STATUS_LOAD_FAILURE = "failed"
 
-# Revision author for deposit
+# Release author for deposit
 SWH_PERSON = {
     "name": "Software Heritage",
     "fullname": "Software Heritage",
