@@ -3,8 +3,6 @@
 # License: GNU General Public License version 3, or any later version
 # See top-level LICENSE file for more information
 
-from io import BytesIO
-
 from django.urls import reverse_lazy as reverse
 from rest_framework import status
 
@@ -12,6 +10,7 @@ from swh.deposit.config import COL_IRI, DEPOSIT_STATUS_LOAD_SUCCESS
 from swh.deposit.models import Deposit
 from swh.deposit.parsers import parse_xml
 from swh.deposit.tests.common import post_atom
+from swh.deposit.utils import NAMESPACES
 
 from ..conftest import internal_create_deposit
 
@@ -39,9 +38,9 @@ def test_add_deposit_with_add_to_origin(
         data=atom_dataset["entry-data-with-add-to-origin"] % origin_url,
     )
 
-    assert response.status_code == status.HTTP_201_CREATED
-    response_content = parse_xml(BytesIO(response.content))
-    deposit_id = response_content["swh:deposit_id"]
+    assert response.status_code == status.HTTP_201_CREATED, response.content.decode()
+    response_content = parse_xml(response.content)
+    deposit_id = int(response_content.findtext("swh:deposit_id", namespaces=NAMESPACES))
 
     assert deposit_id != deposit.id
 
@@ -105,7 +104,7 @@ def test_add_deposit_add_to_wrong_origin(
         data=atom_dataset["entry-data0"] % origin_url,
     )
 
-    assert response.status_code == status.HTTP_403_FORBIDDEN
+    assert response.status_code == status.HTTP_403_FORBIDDEN, response.content.decode()
     assert b"must start with" in response.content
 
 
@@ -150,8 +149,4 @@ def test_post_deposit_atom_403_add_to_wrong_origin_url_prefix(
         HTTP_IN_PROGRESS="true",
     )
     assert response.status_code == status.HTTP_403_FORBIDDEN
-    expected_msg = (
-        f"Cannot create origin {origin_url}, "
-        f"it must start with {deposit_user.provider_url}"
-    )
-    assert expected_msg in response.content.decode()
+    assert "URL mismatch" in response.content.decode()
