@@ -1,14 +1,15 @@
-# Copyright (C) 2017-2021  The Software Heritage developers
+# Copyright (C) 2017-2022  The Software Heritage developers
 # See the AUTHORS file at the top-level directory of this distribution
 # License: GNU General Public License version 3, or any later version
 # See top-level LICENSE file for more information
 
 """Tests the handling of the Atom content when doing a POST Col-IRI."""
 
-from io import BytesIO
+import datetime
 import textwrap
 import uuid
 import warnings
+from xml.etree import ElementTree
 
 import attr
 from django.urls import reverse_lazy as reverse
@@ -22,9 +23,12 @@ from swh.deposit.config import (
     APIConfig,
 )
 from swh.deposit.models import Deposit, DepositCollection, DepositRequest
-from swh.deposit.parsers import parse_xml
 from swh.deposit.tests.common import post_atom
-from swh.deposit.utils import compute_metadata_context, extended_swhid_from_qualified
+from swh.deposit.utils import (
+    NAMESPACES,
+    compute_metadata_context,
+    extended_swhid_from_qualified,
+)
 from swh.model.hypothesis_strategies import (
     directories,
     present_contents,
@@ -121,14 +125,16 @@ def test_post_deposit_atom_201_even_with_decimal(
     # then
     assert response.status_code == status.HTTP_201_CREATED, response.content.decode()
 
-    response_content = parse_xml(BytesIO(response.content))
-    deposit_id = response_content["swh:deposit_id"]
+    response_content = ElementTree.fromstring(response.content)
+    deposit_id = int(response_content.findtext("swh:deposit_id", namespaces=NAMESPACES))
 
     deposit = Deposit.objects.get(pk=deposit_id)
     dr = DepositRequest.objects.get(deposit=deposit)
 
-    assert dr.metadata is not None
-    sw_version = dr.metadata.get("codemeta:softwareVersion")
+    assert dr.raw_metadata is not None
+    sw_version = ElementTree.fromstring(dr.raw_metadata).findtext(
+        "codemeta:softwareVersion", namespaces=NAMESPACES
+    )
     assert sw_version == "10.4"
 
 
@@ -145,6 +151,25 @@ def test_post_deposit_atom_400_with_empty_body(
         data=atom_content,
         HTTP_SLUG="external-id",
     )
+    assert (
+        response.status_code == status.HTTP_400_BAD_REQUEST
+    ), response.content.decode()
+    assert b"Empty body request is not supported" in response.content
+
+
+def test_post_deposit_atom_400_with_empty_request(
+    authenticated_client, deposit_collection
+):
+    """Posting empty request should return a 400 response
+
+    """
+    response = post_atom(
+        authenticated_client,
+        reverse(COL_IRI, args=[deposit_collection.name]),
+        data={},
+        HTTP_SLUG="external-id",
+        CONTENT_LENGTH=0,
+    )
     assert response.status_code == status.HTTP_400_BAD_REQUEST
     assert b"Empty body request is not supported" in response.content
 
@@ -214,11 +239,7 @@ def test_post_deposit_atom_403_create_wrong_origin_url_prefix(
         HTTP_IN_PROGRESS="true",
     )
     assert response.status_code == status.HTTP_403_FORBIDDEN
-    expected_msg = (
-        f"Cannot create origin {origin_url}, "
-        f"it must start with {deposit_user.provider_url}"
-    )
-    assert expected_msg in response.content.decode()
+    assert "URL mismatch" in response.content.decode()
 
 
 def test_post_deposit_atom_use_slug_header(
@@ -242,8 +263,8 @@ def test_post_deposit_atom_use_slug_header(
     )
 
     assert response.status_code == status.HTTP_201_CREATED
-    response_content = parse_xml(BytesIO(response.content))
-    deposit_id = response_content["swh:deposit_id"]
+    response_content = ElementTree.fromstring(response.content)
+    deposit_id = int(response_content.findtext("swh:deposit_id", namespaces=NAMESPACES))
 
     deposit = Deposit.objects.get(pk=deposit_id)
     assert deposit.collection == deposit_collection
@@ -271,8 +292,8 @@ def test_post_deposit_atom_no_origin_url_nor_slug_header(
     )
 
     assert response.status_code == status.HTTP_201_CREATED
-    response_content = parse_xml(BytesIO(response.content))
-    deposit_id = response_content["swh:deposit_id"]
+    response_content = ElementTree.fromstring(response.content)
+    deposit_id = int(response_content.findtext("swh:deposit_id", namespaces=NAMESPACES))
 
     deposit = Deposit.objects.get(pk=deposit_id)
     assert deposit.collection == deposit_collection
@@ -301,8 +322,8 @@ def test_post_deposit_atom_with_slug_and_external_identifier(
     )
 
     assert response.status_code == status.HTTP_201_CREATED
-    response_content = parse_xml(BytesIO(response.content))
-    deposit_id = response_content["swh:deposit_id"]
+    response_content = ElementTree.fromstring(response.content)
+    deposit_id = int(response_content.findtext("swh:deposit_id", namespaces=NAMESPACES))
 
     deposit = Deposit.objects.get(pk=deposit_id)
     assert deposit.collection == deposit_collection
@@ -416,18 +437,27 @@ def test_post_deposit_atom_entry_initial(
     atom_entry_data = atom_dataset["entry-data0"] % origin_url
 
     # when
+    date_before = datetime.datetime.now(tz=datetime.timezone.utc)
     response = post_atom(
         authenticated_client,
         reverse(COL_IRI, args=[deposit_collection.name]),
         data=atom_entry_data,
         HTTP_IN_PROGRESS="false",
     )
+    date_after = datetime.datetime.now(tz=datetime.timezone.utc)
 
     # then
     assert response.status_code == status.HTTP_201_CREATED, response.content.decode()
 
-    response_content = parse_xml(BytesIO(response.content))
-    deposit_id = response_content["swh:deposit_id"]
+    response_content = ElementTree.fromstring(response.content)
+    deposit_id = int(response_content.findtext("swh:deposit_id", namespaces=NAMESPACES))
+    assert (
+        date_before
+        <= datetime.datetime.fromisoformat(
+            response_content.findtext("swh:deposit_date", namespaces=NAMESPACES)
+        )
+        <= date_after
+    )
 
     deposit = Deposit.objects.get(pk=deposit_id)
     assert deposit.collection == deposit_collection
@@ -436,7 +466,6 @@ def test_post_deposit_atom_entry_initial(
 
     # one associated request to a deposit
     deposit_request = DepositRequest.objects.get(deposit=deposit)
-    assert deposit_request.metadata is not None
     assert deposit_request.raw_metadata == atom_entry_data
     assert bool(deposit_request.archive) is False
 
@@ -465,9 +494,9 @@ def test_post_deposit_atom_entry_with_codemeta(
     # then
     assert response.status_code == status.HTTP_201_CREATED
 
-    response_content = parse_xml(BytesIO(response.content))
+    response_content = ElementTree.fromstring(response.content)
 
-    deposit_id = response_content["swh:deposit_id"]
+    deposit_id = int(response_content.findtext("swh:deposit_id", namespaces=NAMESPACES))
 
     deposit = Deposit.objects.get(pk=deposit_id)
     assert deposit.collection == deposit_collection
@@ -476,7 +505,6 @@ def test_post_deposit_atom_entry_with_codemeta(
 
     # one associated request to a deposit
     deposit_request = DepositRequest.objects.get(deposit=deposit)
-    assert deposit_request.metadata is not None
     assert deposit_request.raw_metadata == atom_entry_data
     assert bool(deposit_request.archive) is False
 
@@ -488,7 +516,7 @@ def test_deposit_metadata_invalid(
 
     """
     invalid_swhid = "swh:1:dir :31b5c8cc985d190b5a7ef4878128ebfdc2358f49"
-    xml_data = atom_dataset["entry-data-with-swhid"].format(swhid=invalid_swhid)
+    xml_data = atom_dataset["entry-data-with-swhid-no-prov"].format(swhid=invalid_swhid)
 
     response = post_atom(
         authenticated_client,
@@ -499,6 +527,29 @@ def test_deposit_metadata_invalid(
     assert b"Invalid SWHID reference" in response.content
 
 
+def test_deposit_metadata_invalid_metadata_provenance(
+    authenticated_client, deposit_collection, atom_dataset
+):
+    """Posting invalid metadata provenance is bad request returned to client
+
+    """
+    invalid_swhid = "swh:1:dir:31b5c8cc985d190b5a7ef4878128ebfdc2358f49"
+    xml_data = atom_dataset["entry-data-with-swhid"].format(
+        swhid=invalid_swhid,
+        metadata_provenance_url=(
+            "https://inria.halpreprod.archives-ouvertes.fr/hal-abcdefgh"
+        ),
+    )
+
+    response = post_atom(
+        authenticated_client,
+        reverse(COL_IRI, args=[deposit_collection.name]),
+        data=xml_data,
+    )
+    assert response.status_code == status.HTTP_403_FORBIDDEN
+    assert b"URL mismatch" in response.content
+
+
 def test_deposit_metadata_fails_functional_checks(
     authenticated_client, deposit_collection, atom_dataset
 ):
@@ -543,7 +594,10 @@ def test_deposit_metadata_swhid(
     swhid_reference = QualifiedSWHID.from_string(swhid)
     swhid_target = extended_swhid_from_qualified(swhid_reference)
 
-    xml_data = atom_dataset["entry-data-with-swhid"].format(swhid=swhid)
+    xml_data = atom_dataset["entry-data-with-swhid"].format(
+        swhid=swhid,
+        metadata_provenance_url="https://hal-test.archives-ouvertes.fr/hal-abcdefgh",
+    )
     deposit_client = authenticated_client.deposit_client
 
     _insert_object(swh_storage, swhid_reference)
@@ -555,10 +609,10 @@ def test_deposit_metadata_swhid(
     )
 
     assert response.status_code == status.HTTP_201_CREATED, response.content.decode()
-    response_content = parse_xml(BytesIO(response.content))
+    response_content = ElementTree.fromstring(response.content)
 
     # Ensure the deposit is finalized
-    deposit_id = int(response_content["swh:deposit_id"])
+    deposit_id = int(response_content.findtext("swh:deposit_id", namespaces=NAMESPACES))
     deposit = Deposit.objects.get(pk=deposit_id)
     assert deposit.swhid == str(swhid_target)
     assert deposit.swhid_context == str(swhid_reference)
@@ -633,9 +687,9 @@ def test_deposit_metadata_origin(
     )
 
     assert response.status_code == status.HTTP_201_CREATED, response.content.decode()
-    response_content = parse_xml(BytesIO(response.content))
+    response_content = ElementTree.fromstring(response.content)
     # Ensure the deposit is finalized
-    deposit_id = int(response_content["swh:deposit_id"])
+    deposit_id = int(response_content.findtext("swh:deposit_id", namespaces=NAMESPACES))
     deposit = Deposit.objects.get(pk=deposit_id)
     # we got not swhid as input so we cannot have those
     assert deposit.swhid is None
@@ -710,7 +764,7 @@ def test_deposit_metadata_unknown_swhid(
     """Posting a swhid reference is rejected if the referenced object is unknown
 
     """
-    xml_data = atom_dataset["entry-data-with-swhid"].format(swhid=swhid)
+    xml_data = atom_dataset["entry-data-with-swhid-no-prov"].format(swhid=swhid)
 
     response = post_atom(
         authenticated_client,
@@ -721,8 +775,10 @@ def test_deposit_metadata_unknown_swhid(
     assert (
         response.status_code == status.HTTP_400_BAD_REQUEST
     ), response.content.decode()
-    response_content = parse_xml(BytesIO(response.content))
-    assert "object does not exist" in response_content["sword:error"]["atom:summary"]
+    response_content = ElementTree.fromstring(response.content)
+    assert "object does not exist" in response_content.findtext(
+        "atom:summary", namespaces=NAMESPACES
+    )
 
 
 @pytest.mark.parametrize(
@@ -739,7 +795,7 @@ def test_deposit_metadata_extended_swhid(
     for an extended object type
 
     """
-    xml_data = atom_dataset["entry-data-with-swhid"].format(swhid=swhid)
+    xml_data = atom_dataset["entry-data-with-swhid-no-prov"].format(swhid=swhid)
 
     response = post_atom(
         authenticated_client,
@@ -750,8 +806,10 @@ def test_deposit_metadata_extended_swhid(
     assert (
         response.status_code == status.HTTP_400_BAD_REQUEST
     ), response.content.decode()
-    response_content = parse_xml(BytesIO(response.content))
-    assert "Invalid SWHID reference" in response_content["sword:error"]["atom:summary"]
+    response_content = ElementTree.fromstring(response.content)
+    assert "Invalid SWHID reference" in response_content.findtext(
+        "atom:summary", namespaces=NAMESPACES
+    )
 
 
 def test_deposit_metadata_unknown_origin(
@@ -771,5 +829,7 @@ def test_deposit_metadata_unknown_origin(
     assert (
         response.status_code == status.HTTP_400_BAD_REQUEST
     ), response.content.decode()
-    response_content = parse_xml(BytesIO(response.content))
-    assert "known to the archive" in response_content["sword:error"]["atom:summary"]
+    response_content = ElementTree.fromstring(response.content)
+    assert "known to the archive" in response_content.findtext(
+        "atom:summary", namespaces=NAMESPACES
+    )
